Authors
=======
    Contributors of code, tests and documentation to the project who have agreed to have their work enjoined into the project and project license (BSD).


Acknowledgment
--------------
    * PR #15 by RobertCochran
    * PR #12 by erans
    * ftpretty by codebynumbers
    * paramiko by Robey Pointer
    * pysftp by dundeemt
    * ssh.py by Zeth
